@@ -103,37 +103,42 @@ extract_polygons_and_points <- function(x) {
 #'
 #' @noRd
 empty_wdpa_dataset <- function(crs) {
-  sf::st_sf(tibble::tibble(
-    WDPAID = numeric(0),
-    WDPA_PID = character(0),
-    PA_DEF = character(0),
-    NAME = character(0),
-    ORIG_NAME = character(0),
-    DESIG = character(0),
-    DESIG_ENG = character(0),
-    DESIG_TYPE = character(0),
-    IUCN_CAT = character(0),
-    INT_CRIT = character(0),
-    MARINE = character(0),
-    REP_M_AREA = numeric(0),
-    REP_AREA = numeric(0),
-    NO_TAKE = character(0),
-    NO_TK_AREA = numeric(0),
-    STATUS = character(0),
-    STATUS_YR = numeric(0),
-    GOV_TYPE = character(0),
-    OWN_TYPE = character(0),
-    MANG_AUTH = character(0),
-    MANG_PLAN = character(0),
-    VERIF =  character(0),
-    METADATAID = integer(0),
-    SUB_LOC = character(0),
-    PARENT_ISO = character(0),
-    ISO3 = character(0),
-    SUPP_INFO = character(0),
-    CONS_OBJ = character(0),
-    GEOMETRY_TYPE = character(0),
-    AREA_KM2 = numeric(0)),
+  sf::st_sf(
+    tibble::tibble(
+      SITE_ID = integer(0),
+      SITE_PID = character(0),
+      SITE_TYPE = character(0),
+      NAME_ENG = character(0),
+      NAME = character(0),
+      DESIG = character(0),
+      DESIG_ENG = character(0),
+      DESIG_TYPE = character(0),
+      IUCN_CAT = character(0),
+      INT_CRIT = character(0),
+      REALM = character(0),
+      REP_M_AREA = numeric(0),
+      REP_AREA = numeric(0),
+      NO_TAKE = character(0),
+      NO_TK_AREA = numeric(0),
+      STATUS = character(0),
+      STATUS_YR = numeric(0),
+      GOV_TYPE = character(0),
+      GOVSUBTYPE = character(0),
+      OWN_TYPE = character(0),
+      OWNSUBTYPE = character(0),
+      MANG_AUTH = character(0),
+      MANG_PLAN = character(0),
+      VERIF = character(0),
+      METADATAID = integer(0),
+      PRNT_ISO3 = character(0),
+      ISO3 = character(0),
+      SUPP_INFO = character(0),
+      CONS_OBJ = character(0),
+      INLND_WTRS = character(0),
+      OECM_ASMT = character(0),
+      GEOMETRY_TYPE = character(0),
+      AREA_KM2 = numeric(0)
+    ),
     geometry = sf::st_sfc(crs = crs))
 }
 
